searchData={"items":[{"type":"module","title":"Search","doc":"**⚡ Fast full-text search for Elixir**\n\nThis library provides simple, fast, in-memory full-text search functionality\nfor Elixir applications.\n\n> 👷 **Warning**\n>\n> This library is built on a solid foundation but is still under heavy\n> development.","ref":"Search.html"},{"type":"module","title":"Features - Search","doc":"- 🧠 Memory efficient indexing of documents\n- 🔎 Exact match search\n- 🏃 Prefix search\n- 🔜 Fuzzy search\n- 🔜 Auto-suggestion engine\n- 🔢 Modern search result ranking algorithm\n- 🔀 Add and remove documents anytime","ref":"Search.html#module-features"},{"type":"module","title":"Usage - Search","doc":"","ref":"Search.html#module-usage"},{"type":"module","title":"Creating an Index - Search","doc":"To create a new index, use the `new/1` function with a list of fields to be\nindexed:\n\n    index = Search.new(fields: [:title, :content])","ref":"Search.html#module-creating-an-index"},{"type":"module","title":"Adding Documents - Search","doc":"To add a document to the index, use the `add/2` function with the index and\nthe document:\n\n    document = %{id: 1, title: \"Elixir\", content: \"Elixir is a dynamic, functional language.\"}\n    index = Search.add!(index, document)\n\nYou can also add multiple documents at once:\n\n    documents = [\n      %{id: 2, title: \"Phoenix\", content: \"Phoenix is a web framework for Elixir.\"},\n      %{id: 3, title: \"Nerves\", content: \"Nerves is a framework for embedded systems.\"}\n    ]\n    index = Search.add!(index, documents)","ref":"Search.html#module-adding-documents"},{"type":"module","title":"Removing Documents - Search","doc":"To remove a document from the index, use the `remove/2` function with the\nindex and the document:\n\n    index = Search.remove!(index, document)\n\nYou can also remove multiple documents at once:\n\n    index = Search.remove!(index, documents)","ref":"Search.html#module-removing-documents"},{"type":"module","title":"Searching - Search","doc":"To search the index, use the `search/3` function with the index and the query\nstring:\n\n    Search.search(index, \"Elixir\")\n    [\n      %{\n        id: 1,\n        matches: %{\"elixir\" => [:title, :content]},\n        fields: %{},\n        terms: [\"elixir\"],\n        score: 2.194907312448878\n      },\n      %{\n        id: 2,\n        matches: %{\"elixir\" => [:content]},\n        fields: %{},\n        terms: [\"elixir\"],\n        score: 0.6962007371655166\n      }\n    ]","ref":"Search.html#module-searching"},{"type":"module","title":"Internals - Search","doc":"The library uses a Radix tree for efficient indexing and retrieval of terms.\nIt also implements the BM25 algorithm for relevance scoring.","ref":"Search.html#module-internals"},{"type":"function","title":"Search.add/2","doc":"Adds a document or a list of documents to the index.","ref":"Search.html#add/2"},{"type":"function","title":"Parameters - Search.add/2","doc":"- `index`: The current index state.\n  - `document`: A map representing a single document or a list of such maps.","ref":"Search.html#add/2-parameters"},{"type":"function","title":"Returns - Search.add/2","doc":"- The updated index with the new document(s) added.","ref":"Search.html#add/2-returns"},{"type":"function","title":"Examples - Search.add/2","doc":"iex> index = Search.new(fields: [:title, :content])\n    iex> document = %{id: 1, title: \"Elixir\", content: \"Elixir is a dynamic, functional language.\"}\n    iex> {:ok, index} = Search.add(index, document)\n    iex> documents = [\n    ...>   %{id: 2, title: \"Phoenix\", content: \"Phoenix is a web framework for Elixir.\"},\n    ...>   %{id: 3, title: \"Nerves\", content: \"Nerves is a framework for embedded systems.\"}\n    ...> ]\n    iex> {:ok, index} = Search.add(index, documents)","ref":"Search.html#add/2-examples"},{"type":"function","title":"Search.add!/2","doc":"Adds a document or a list of documents to the index like `add/2`, but raises\nif an error occurs.","ref":"Search.html#add!/2"},{"type":"function","title":"Search.new/1","doc":"Creates a new search index.","ref":"Search.html#new/1"},{"type":"function","title":"Parameters - Search.new/1","doc":"- opts: A keyword list of options.\n    - `fields` - A list of fields to be indexed.\n    - `return_field_data` - (Optional) A list of fields to be returned with search results.","ref":"Search.html#new/1-parameters"},{"type":"function","title":"Returns - Search.new/1","doc":"- A new `%Index{}` struct.","ref":"Search.html#new/1-returns"},{"type":"function","title":"Examples - Search.new/1","doc":"iex> index = Search.new(fields: [:title, :content])","ref":"Search.html#new/1-examples"},{"type":"function","title":"Search.query_exact_terms/2","doc":"","ref":"Search.html#query_exact_terms/2"},{"type":"function","title":"Search.query_prefixed_terms/4","doc":"","ref":"Search.html#query_prefixed_terms/4"},{"type":"function","title":"Search.remove/2","doc":"Removes a document or a list of documents from the index. The document(s) must be unchanged.","ref":"Search.html#remove/2"},{"type":"function","title":"Parameters - Search.remove/2","doc":"- `index`: The current index state.\n  - `document`: A map representing a single document or a list of such maps to be removed.","ref":"Search.html#remove/2-parameters"},{"type":"function","title":"Returns - Search.remove/2","doc":"- The updated index with the document(s) removed.","ref":"Search.html#remove/2-returns"},{"type":"function","title":"Examples - Search.remove/2","doc":"iex> index = Search.new(fields: [:title, :content])\n    iex> document = %{id: 1, title: \"Elixir\", content: \"Elixir is a dynamic, functional language.\"}\n    iex> index = Search.add!(index, document)\n    iex> {:ok, index} = Search.remove(index, document)\n    iex> documents = [\n    ...>   %{id: 2, title: \"Phoenix\", content: \"Phoenix is a web framework for Elixir.\"},\n    ...>   %{id: 3, title: \"Nerves\", content: \"Nerves is a framework for embedded systems.\"}\n    ...> ]\n    iex> index = Search.add!(index, documents)\n    iex> {:ok, index} = Search.remove(index, documents)","ref":"Search.html#remove/2-examples"},{"type":"function","title":"Search.remove!/2","doc":"Removes a document or a list of documents from the index like `remove/2`, but raises\nif an error occurs.","ref":"Search.html#remove!/2"},{"type":"function","title":"Search.search/3","doc":"Searches the index for documents matching the given query string.","ref":"Search.html#search/3"},{"type":"function","title":"Parameters - Search.search/3","doc":"- `index`: The current index state.\n  - `query_string`: The search query string.\n  - `opts`: The search options.\n    - `prefix?`: Whether to perform a prefix search. Defaults to `false`.\n    - `weights`: The weights to use for the search. Defaults to `[prefix: 0.375]`.","ref":"Search.html#search/3-parameters"},{"type":"function","title":"Returns - Search.search/3","doc":"- A list of maps representing the search results, sorted by relevance score in descending order. Each map contains:\n    - `id` - The document ID.\n    - `fields` - The fields returned with the search results.\n    - `score` - The relevance score of the document.\n    - `terms` - The terms that matched in the document.\n    - `matches` - The fields in which the terms matched.","ref":"Search.html#search/3-returns"},{"type":"function","title":"Examples - Search.search/3","doc":"iex> index = Search.new(fields: [:title, :content])\n    iex> document = %{id: 1, title: \"Elixir\", content: \"Elixir is a dynamic, functional language.\"}\n    iex> index = Search.add!(index, document)\n    iex> Search.search(index, \"Elixir\")\n    [\n      %{\n        id: 1,\n        fields: %{},\n        score: 0.8630462173553426,\n        terms: [\"elixir\"],\n        matches: %{\"elixir\" => [:title, :content]}\n      }\n    ]\n    iex> Search.search(index, \"Eli\", prefix?: true)\n    [\n      %{\n        id: 1,\n        fields: %{},\n        score: 0.28142811435500303,\n        terms: [\"elixir\"],\n        matches: %{\"elixir\" => [:title, :content]}\n      }\n    ]","ref":"Search.html#search/3-examples"},{"type":"module","title":"Search.Index","doc":"","ref":"Search.Index.html"},{"type":"type","title":"Search.Index.t/0","doc":"","ref":"Search.Index.html#t:t/0"},{"type":"exception","title":"Search.DocumentExistsError","doc":"Raised when a document already exists in the index.","ref":"Search.DocumentExistsError.html"},{"type":"exception","title":"Search.DocumentFieldNotString","doc":"Raised when a document field does not implement String.Chars.","ref":"Search.DocumentFieldNotString.html"},{"type":"exception","title":"Search.DocumentMissingIdError","doc":"Raised when a document is missing an ID.","ref":"Search.DocumentMissingIdError.html"},{"type":"exception","title":"Search.DocumentMutatedError","doc":"Raised when a document has been mutated since it was added to the index.","ref":"Search.DocumentMutatedError.html"},{"type":"exception","title":"Search.DocumentNotExistsError","doc":"Raised when a document does not exist in the index.","ref":"Search.DocumentNotExistsError.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}